==> haskell-citeproc-0.8.1-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 citeproc
version:              0.8.1
visibility:           public
id:                   citeproc-0.8.1-FGobPf4SzfgHLXV9bDCESi
key:                  citeproc-0.8.1-FGobPf4SzfgHLXV9bDCESi
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  821190486e0a275c0fcbc6e676868209
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.2.8/site-local/citeproc-0.8.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/citeproc-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1-FGobPf4SzfgHLXV9bDCESi
depends:
    aeson-2.1.2.1-F86TtVKFNKJLpW409aVG0j
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-GWeOjNQL6o11YPoz7mZGER
    containers-0.6.5.1 data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    pandoc-types-1.23.1-DdQZgf4FErf8aiJPYPPwhY
    safe-0.3.21-CqIHKdkgiB2klcxc5dxay
    scientific-0.3.7.0-72r9rPpXaeUjwM4XNBSJR text-1.2.5.0
    text-icu-0.8.0.5-G1xfUyu0pVRECKe4sigVqt transformers-0.5.6.2
    unicode-collation-0.1.3.6-CQRRSp3DARyCZWgBXKOEpR
    uniplate-1.6.13-2wlaKTDzX4U4sRJV09tewv
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe
    xml-conduit-1.9.1.3-EZ6ANdSJD1O1xgN6ayPuaM

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-citeproc-0.8.1-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 citeproc
version:              0.8.1
visibility:           public
id:                   citeproc-0.8.1-6UsenmjK8KCK8PiuLg7QBz
key:                  citeproc-0.8.1-6UsenmjK8KCK8PiuLg7QBz
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  394f27f095d90bef838a0dcb6d3f8601
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.2.8/site-local/citeproc-0.8.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/citeproc-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1-6UsenmjK8KCK8PiuLg7QBz
depends:
    aeson-2.1.2.1-3YQjfXPQMsb4U9de9kBzUF
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-GWeOjNQL6o11YPoz7mZGER
    containers-0.6.5.1 data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    pandoc-types-1.23.1-LmwxUzeDkzQ1RvrvSWc0fV
    safe-0.3.21-CqIHKdkgiB2klcxc5dxay
    scientific-0.3.7.0-72r9rPpXaeUjwM4XNBSJR text-1.2.5.0
    text-icu-0.8.0.5-G1xfUyu0pVRECKe4sigVqt transformers-0.5.6.2
    unicode-collation-0.1.3.6-CQRRSp3DARyCZWgBXKOEpR
    uniplate-1.6.13-2wlaKTDzX4U4sRJV09tewv
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe
    xml-conduit-1.9.1.3-2x4d78AN6G9sdWplW1Etj

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
